@@ -13,11 +13,17 @@ from quark.utils.colors import (
     bold,
     yellow,
     green,
+    lightblue,
+    magenta,
+    lightyellow,
 )
 from quark.utils.graph import call_graph
 from quark.utils.out import print_info, print_success
 from quark.utils.output import output_parent_function_table, output_parent_function_json
 from quark.utils.weight import Weight
+import pandas as pd
+import os
+import numpy as np
 
 MAX_SEARCH_LAYER = 3
 CHECK_LIST = "".join(["\t[" + "\u2713" + "]"])
@@ -219,7 +225,9 @@ class Quark:
         self.quark_analysis.crime_description = rule_obj.crime
 
         # Level 1: Permission Check
-        if set(rule_obj.permission).issubset(set(self.apkinfo.permissions)):
+        if self.apkinfo.ret_type == "DEX":
+            rule_obj.check_item[0] = True
+        elif set(rule_obj.permission).issubset(set(self.apkinfo.permissions)):
             rule_obj.check_item[0] = True
         else:
             # Exit if the level 1 stage check fails.
@@ -383,9 +391,10 @@ class Quark:
         # add the score
         self.quark_analysis.score_sum += score
 
-    def add_table_row(self, rule_obj, confidence, score, weight):
+    def add_table_row(self, name, rule_obj, confidence, score, weight):
 
         self.quark_analysis.summary_report_table.add_row([
+            name,
             green(rule_obj.crime),
             yellow(confidence),
             score,
@@ -404,20 +413,81 @@ class Quark:
         conf = rule_obj.check_item.count(True)
         weight = rule_obj.get_score(conf)
         score = rule_obj.score
+        name = rule_obj.rule_filename
 
         if threshold:
 
             if rule_obj.check_item.count(True) * 20 >= int(threshold):
-                self.add_table_row(rule_obj, confidence, score, weight)
+                self.add_table_row(name, rule_obj, confidence, score, weight)
 
         else:
-            self.add_table_row(rule_obj, confidence, score, weight)
+            self.add_table_row(name, rule_obj, confidence, score, weight)
 
         # add the weight
         self.quark_analysis.weight_sum += weight
         # add the score
         self.quark_analysis.score_sum += score
 
+    def show_label_report(self, rule_path, all_labels, table_version):
+        """
+        Show the report based on label, last column represents max confidence for that label
+        :param rule_path: the path where may be present the file label_desc.csv.
+        :param all_labels: dictionary containing label:<array of confidence values associated to that label>
+        :return: None
+        """
+        label_desc = {}
+        # clear table to manage max/detail version
+        self.quark_analysis.label_report_table.clear()
+        if os.path.isfile(os.path.join(rule_path, "label_desc.csv")):
+            # associate to each label a description
+            col_list = ["label", "description"]
+            # csv file on form <label,description>
+            # put this file in the folder of rules (it must not be a json file since it could create conflict with management of rules)
+            df = pd.read_csv(
+                os.path.join(rule_path, "label_desc.csv"), usecols=col_list
+            )
+            label_desc = dict(zip(df["label"], df["description"]))
+
+        for label_name in all_labels:
+            confidences = np.array(all_labels[label_name])
+
+            if table_version == "max":
+                self.quark_analysis.label_report_table.field_names = [
+                    "Label",
+                    "Description",
+                    "Number of rules",
+                    "MAX Confidence %",
+                ]
+                self.quark_analysis.label_report_table.add_row(
+                    [
+                        green(label_name),
+                        yellow(label_desc.get(label_name, "-")),
+                        (len(confidences)),
+                        red(np.max(confidences)),
+                    ]
+                )
+            else:
+                self.quark_analysis.label_report_table.field_names = [
+                    "Label",
+                    "Description",
+                    "Number of rules",
+                    "MAX Confidence %",
+                    "AVG Confidence",
+                    "Std Deviation",
+                    "# of Rules with Confidence >= 80%",
+                ]
+                self.quark_analysis.label_report_table.add_row(
+                    [
+                        green(label_name),
+                        yellow(label_desc.get(label_name, "-")),
+                        (len(confidences)),
+                        red(np.max(confidences)),
+                        magenta(round(np.mean(confidences), 2)),
+                        lightblue(round(np.std(confidences), 2)),
+                        lightyellow(np.count_nonzero(confidences >= 80)),
+                    ]
+                )
+
     def show_detail_report(self, rule_obj):
         """
         Show the detail report.
