@@ -14,13 +14,26 @@ from quark.Objects.quarkrule import QuarkRule
 from quark.logo import logo
 from quark.utils.out import print_success, print_info, print_warning
 from quark.utils.weight import Weight
+from quark.utils.colors import yellow
 
 logo()
 
 
 @click.command(no_args_is_help=True)
-@click.option("-s", "--summary", is_flag=True, help="Show summary report")
-@click.option("-d", "--detail", is_flag=True, help="Show detail report")
+@click.option(
+    "-s",
+    "--summary",
+    is_flag=False,
+    flag_value="all_rules",
+    help="Show summary report",
+)
+@click.option(
+    "-d",
+    "--detail",
+    is_flag=False,
+    flag_value="all_rules",
+    help="Show detail report",
+)
 @click.option(
     "-o",
     "--output",
@@ -79,6 +92,13 @@ logo()
     is_flag=True,
     required=False,
 )
+@click.option(
+    "-l",
+    "--label",
+    help="Show report based on label of rules",
+    type=click.Choice(["max", "detailed"]),
+    required=False,
+)
 def entry_point(
     summary,
     detail,
@@ -90,6 +110,7 @@ def entry_point(
     threshold,
     list,
     permission,
+    label,
 ):
     """Quark is an Obfuscation-Neglect Android Malware Scoring System"""
 
@@ -99,12 +120,61 @@ def entry_point(
     # Load rules
     rules_list = [x for x in os.listdir(rule) if x.endswith("json")]
 
-    # Show summary report
-    if summary:
+    if label:
+        all_labels = {}
+        # dictionary containing
+        # key: label
+        # value: list of confidence values
+        # $ print(all_rules["accessibility service"])
+        # > [60, 40, 60, 40, 60, 40]
 
         for single_rule in tqdm(rules_list):
             rulepath = os.path.join(rule, single_rule)
             rule_checker = QuarkRule(rulepath)
+            # Run the checker
+            data.run(rule_checker)
+            confidence = rule_checker.check_item.count(True) * 20
+            labels = rule_checker._label  # array type, e.g. ['network', 'collection']
+            for single_label in labels:
+                if single_label in all_labels:
+                    all_labels[single_label].append(confidence)
+                else:
+                    all_labels[single_label] = [confidence]
+
+        # get how many label with max confidence >= 80%
+        counter_high_confidence = 0
+        for single_label in all_labels:
+            if max(all_labels[single_label]) >= 80:
+                counter_high_confidence += 1
+
+        print_info("Total Label found: " + yellow(str(len(all_labels))))
+        print_info(
+            "Rules with label which max confidence >= 80%: "
+            + yellow(str(counter_high_confidence))
+        )
+
+        data.show_label_report(rule, all_labels, label)
+        print(data.quark_analysis.label_report_table)
+
+    # Show summary report
+    if summary:
+
+        if summary == "all_rules":
+            label_flag = False
+        elif summary.endswith("json"):
+            rules_list = [summary]
+            label_flag = False
+        else:
+            label_flag = True
+
+        for single_rule in tqdm(rules_list):
+            rulepath = os.path.join(rule, single_rule)
+            rule_checker = QuarkRule(rulepath)
+
+            labels = rule_checker._label
+            if label_flag:
+                if summary not in labels:
+                    continue
 
             # Run the checker
             data.run(rule_checker)
@@ -124,14 +194,28 @@ def entry_point(
     # Show detail report
     if detail:
 
+        if detail == "all_rules":
+            label_flag = False
+        elif detail.endswith("json"):
+            rules_list = [detail]
+            label_flag = False
+        else:
+            label_flag = True
+
         for single_rule in tqdm(rules_list):
             rulepath = os.path.join(rule, single_rule)
-            print(rulepath)
             rule_checker = QuarkRule(rulepath)
 
+            labels = rule_checker._label
+            if label_flag:
+                if detail not in labels:
+                    continue
+
             # Run the checker
             data.run(rule_checker)
 
+            print("Rulepath: " + rulepath)
+            print("Rule crime: " + rule_checker._crime)
             data.show_detail_report(rule_checker)
             print_success("OK")
 
